@@ -149,6 +149,8 @@ END
 
    TRACKS   => 'Tracks',
 
+   SELECT_TRACKS   => 'Select Tracks',
+
    TRACK_SELECT   => 'Search for Specific Tracks',
 
    TRACK_NAME     => 'Track name',
@@ -185,7 +187,9 @@ END
 
    CONFIGURE_TRACKS   => 'Configure tracks...',
 
-   SELECT_SUBTRACKS   => 'Click to select subtracks...',
+   SUBTRACK_INSTRUCTIONS   => 'Select the tracks you wish to display. Sort the tracks by clicking on the column headings, or by clicking and dragging rows into position.',
+
+   SELECT_SUBTRACKS   => '%d of %d subtracks selected',
 
    EDIT       => 'Edit File...',
 
@@ -442,6 +446,10 @@ END
 
  ADD_YOUR_OWN_TRACKS => 'Add custom tracks',
 
+ ADD_DESCRIPTION    => 'Click to add a description',
+
+ CONFIGURATION     => 'Configuration',
+
  INVALID_SOURCE    => 'The source named %s is invalid.',
 
  NO_SEGMENT        => 'No genomic region selected.',
@@ -456,6 +464,34 @@ END
 
  GLYPH            => 'Shape',
 
+ XYPLOT_TYPE      => 'xyplot subtype',
+
+ WHISKERS_TYPE      => 'whiskers subtype',
+
+ BICOLOR_PIVOT    => 'Switch colors when value crosses',
+
+ BICOLOR_PIVOT_VALUE    => 'Switch point value',
+
+ BICOLOR_PIVOT_POS_COLOR    => 'Color above switch point',
+
+ BICOLOR_PIVOT_NEG_COLOR    => 'Color below switch point',
+
+ WHISKER_MEAN_COLOR    => 'Color from 0 to mean value',
+
+ WHISKER_STDEV_COLOR    => 'Color from mean to stdev value',
+
+ WHISKER_MAX_COLOR    => 'Color from stdev to min/max value',
+
+ SCALE_MIN        => 'Minimum scale value',
+
+ SCALE_MAX        => 'Maximum scale value',
+
+ SHOW_VARIANCE    => 'Show variance band',
+
+ APPLY_CONFIG     => 'Apply this config when region >=',
+
+ SHOW_SUMMARY     => 'Show summary when region >=',
+
  LINEWIDTH        => 'Line width',
 
  STRANDED         => 'Show strand',
@@ -490,7 +526,7 @@ END
 
  ABOUT_THIS_TRACK   => '<b>About this track</b>',
 
- SUBTRACKS_SHOWN    => 'This track contains selectable subtracks:',
+ SUBTRACKS_SHOWN    => 'This track contains selectable subtracks. Click to modify the selection or change subtrack order.',
 
  SHOW_SUBTRACKS     => '<b>Select subtracks</b>',
 
@@ -503,7 +539,7 @@ END
  SHARE              => 'Share %s',
 
  SHARE_INSTRUCTIONS_BOOKMARK => <<END,
-To <b>share</b this track with another user, copy the URL below and
+To <b>share</b> this track with another user, copy the URL below and
 send it to him or her.
 END
 
