@@ -6,7 +6,9 @@ function initAutocomplete() {
 	                 "landmark_search_field",
                          "autocomplete_choices",
                     	 document.URL,
-                         {indicator:          'indicator1',
+                         {
+			 // indicator:          'indicator1',
+			  frequency: 0.2,
                           parameters:         'action=autocomplete',
                           paramName:          'prefix',
 			  minChars:           2
