@@ -1,6 +1,6 @@
 package Bio::Graphics::Browser2::Session;
 
-# $Id: Session.pm 22793 2010-03-10 22:35:40Z lstein $
+# $Id: Session.pm 23146 2010-05-07 05:49:29Z lstein $
 
 use strict;
 use warnings;
@@ -132,7 +132,7 @@ sub lock_nfs {
     my $lock     = File::NFSLock->new(
 	{file               => $lockpath,
 	 lock_type          => $type eq 'exclusive' ? LOCK_EX : LOCK_SH,
-	 blocking_timeout   => 10, # 10 sec
+	 blocking_timeout   => 5,  # 5 sec
 	 stale_lock_timeout => 60, # 1 min
 	});
     warn  "[$$] ...timeout waiting for lock" unless $lock;
@@ -189,7 +189,7 @@ sub mysql_lock_name {
 sub flush {
   my $self = shift;
   return unless $$ == $self->{pid};
-  warn "[$$] session flush for ",$self->id, " ($self)" if DEBUG;
+  carp "[$$] session flush for ",$self->id, " ($self)" if DEBUG;
   $self->{session}->flush if $self->{session};
   $self->unlock;
   warn "[$$] SESSION FLUSH ERROR: ",$self->{session}->errstr 
@@ -238,7 +238,6 @@ sub source {
 
 sub private {
     my $self = shift;
-    if (@_) { carp @_ }
     my $private = $self->{session}->param('.private');
     $self->{session}->param('.private' => shift()) if @_;
     return $private;
