@@ -60,19 +60,26 @@ sub elements {
     my $self = shift;
     return $self->{_elements} if exists $self->{_elements};
     my $index = 1;  # not zero
-    my %elements;
+    my (%elements,$at_least_one_selected);
 
     my $rows  = $self->rows;
     for my $r (@$rows) {
 	my @data   = @$r;
-	my @fields      = grep {!/^[=*]/}        @data;
+	my @fields      = grep {!/^[=*:]/}        @data;
 	my ($id)        = grep {length} map {/^=([\d\w]+)/ && $1 } @data;
+	my ($label)     = grep {length} map {/^:(.+)/      && $1 } @data;
 	my ($selected)  = grep {$_ eq '*'}       @data;
 	$id           ||= join ';',map {/^~(.+)/ ? $1 : $_} @fields;
 	$elements{$id} = { index    => $index++,
 			   selected => $selected,
+			   label    => $label || '',
 			   fields   => \@fields };
+	$at_least_one_selected++ if $selected;
     }
+    unless ($at_least_one_selected) {
+	$elements{$_}{selected}++ foreach keys %elements;
+    }
+	
     return $self->{_elements}=\%elements;
 }
 
@@ -275,7 +282,9 @@ sub feature_to_id_sub {
     my @selectors = $self->selectors();
     my $elements  = $self->elements;
 
-    my $sub = "sub {no warnings; my \$f = shift;my \$found;\n";
+    my $sub = "sub {no warnings; my \$f = shift;\nmy \$found;\n";
+    $sub   .= "if (\$f->type eq 'group') { \n";
+    $sub   .= "\$f = (\$f->get_SeqFeatures)[0] || return \$f->primary_id; }\n";
 
     for my $e (sort {$elements->{$a}{index} <=> $elements->{$b}{index}} keys %$elements) {
 	my $r = $elements->{$e}{fields};
@@ -288,7 +297,9 @@ sub feature_to_id_sub {
 		my $bang = $val ? '' : '!';
 		$sub .= "\$found &&= $bang\$f->has_tag('$operand');\n";
 	    } else {
-		my $operation = $val =~ /^~(.+)/ ? "=~ m[$1]i" : "eq '$val'";
+		my $operation =  $val =~ /^~(.+)/                         ? "=~ m[$1]i" 
+                               : $val =~ /^[+-]?\d*(\.\d+)?([eE]-?\d+)?$/ ? "== $val"
+                               : "eq '$val'";
 		if ($op eq 'tag_value') {
 		    $sub .= "\$found &&= \$f->has_tag('$operand');\n";
 		    $sub .= "\$found &&= (\$f->get_tag_values('$operand'))[0] $operation;\n";
@@ -301,9 +312,15 @@ sub feature_to_id_sub {
     }
     $sub .= "return;\n}";
     my $as =  eval $sub;
-    warn $@ unless $as;
+    warn "sutrack filter failed: ",$@ unless $as;
     return $self->{_feature2id} = $as;
+}
 
+sub id2label {
+    my $self = shift;
+    my $element_id = shift;
+    my $e = $self->elements;
+    return $e->{$element_id}{label} || $element_id;
 }
 
 sub selected_ids {
@@ -311,7 +328,7 @@ sub selected_ids {
     my $elements = $self->elements;
     my %selected = map {$_=>$elements->{$_}{index}} 
                    grep {$elements->{$_}{selected}} keys %$elements;
-    return \%selected;
+    return wantarray ? keys %selected : \%selected;
 }
 
 
@@ -321,7 +338,7 @@ sub filter_feature_sub {
     my $to_id    = $self->feature_to_id_sub or return;
     return sub {
 	my $feature = shift;
-	my $id      = $to_id->($feature);
+	my $id      = $to_id->($feature) or return;
 	return      defined $selected->{$id};
     }
 }
@@ -405,10 +422,10 @@ sub infer_settings_from_source {
 
     return unless @dimensions && @rows;
 
-    my %aliases;
-    if (my $aliases = $source->setting($label=>'subtrack labels')) {
-	%aliases    = map {shellwords($_)} split ';',$aliases;
-    }
+    my $aliases     = $source->setting($label=>'subtrack select labels') 
+	            ||$source->setting($label=>'subtrack labels') ; # deprecated API
+
+    my %aliases    = map {shellwords($_)} split ';',$aliases if $aliases;
     return (\@dimensions,\@rows,\%aliases);
 }
 
